<?php
namespace Modules\Relatorio\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Util\SupUtilities;

class EqualizacaoFornecedores extends \Zeedhi\Framework\Controller\Report {
  
  protected $birtStrategy;
  protected $supUtilities;
  protected $stNomeRel;
  protected $connection;
  protected $environment;
  protected $newCodeSC;

  public function __construct(ReportService $reportService, $birtStrategy, SupUtilities $supUtilities, $connection, $environment, $newCodeSC){
    parent::__construct($reportService);
    $this->birtStrategy = $birtStrategy;
    $this->supUtilities = $supUtilities;
    $this->connection = $connection;
    $this->environment = $environment;
    $this->newCodeSC = $newCodeSC;
  }
  
  private function generateNewCode($tableName) {
    return $this->newCodeSC->getCodeByTableName($tableName, $this->environment->getNrOrg());
  }
  
  protected $reportMapping = array ();
  
  public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
  {
    try{
      $row = $request->getRow();
      $row['IDVERIFICAVRIT'] = 'S'; //este parâmetro será padrão para esta tela

      $row['NRSEQAPUR'] = $this->generateNewCode("EQUALFORNE");
      $this->executeProcedureApuraEqualizacao($row);
      $this->executeProcedureApuraMelhorEqualizacao($row);

      $this->birtStrategy->setReportFormat($row['REPORT_EXTENSION']);
      $this->birtStrategy->setViewMode('preview');
      $this->stNomeRel = $this->getReportName($row);

      
      $this->reportMapping[$this->stNomeRel] =
        array (
          'strategy' => 'BIRT',
          'parameterMapping' => 
          array (
            'CDFILIAL' => 'P_CDCENTCMP',
            'NRSEQAPUR' => 'P_NRSEQAPUR',
            'NRORG' => 'P_NRORG',
            'DTINIVALITM' => 'P_DTINIVALITM',
            'DTFINVALITM' => 'P_DTFINVALITM',
            'NMPRODINIFORMAT' => 'P_NMPRODINI',
            'NMPRODFINFORMAT' => 'P_NMPRODFIN',
            'PARAMCOMPPRECO' => 'P_IDTPCOMPARA',
            'PARAMMELHORPRECO' => 'P_MELHORPRECO',
            'TOTALIZADOR' => 'P_TOTALIZADOR',
            'NMREGIAOFORMAT' => 'P_NMREGIAO',
            'EXIBEMARCA' => 'P_EXIBEMARCA',
            'EXIBEQTCOMPRAR' => 'P_EXIBEQTCOMPRAR',
            'EXIBEVRANTERIOR' => 'P_EXIBEVRANTERIOR',
            'EXIBEVRTOTALANTERIOR' => 'P_EXIBEVRTOTALANTERIOR',
            'EXIBETOTALATUAL' => 'P_EXIBETOTALATUAL',
            'EXIBEVARIACAO' => 'P_EXIBEVARIACAO',
            'EXIBEVRECO' => 'P_EXIBEVRECO',
            'EXIBETOTALECO' => 'P_EXIBETOTALECO',
            'EXIBETOTALOBJ' => 'P_EXIBETOTALOBJ',
            'EXIBEVARIACAONEG' => 'P_EXIBEVARIACAONEG',
            'EXIBETOTALNEG' => 'P_EXIBETOTALNEG'
          ),
      );
    } catch (\Exception $e) {
      throw $e;
    }
  }

  private function executeProcedureApuraEqualizacao($row)
	{
      $dtIniValItm = isset($row['DTVALITM']['start']) ? $row['DTVALITM']['start'] : '';
      $dtFinValItm = isset($row['DTVALITM']['end']) ? $row['DTVALITM']['end'] : '';
      $dtIniValAnt = isset($row['DTVALANT']['start']) ? $row['DTVALANT']['start'] : '';
      $dtFinValAnt = isset($row['DTVALANT']['end']) ? $row['DTVALANT']['end'] : '';
      
      $procedure = new StoredProcedure($this->connection, 'APURA_EQUALIZACAO');
      $procedure->addParam(new Param('P_NREQUALFORNE', Param::PARAM_INPUT, $row['NRSEQAPUR'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDREGIAO', Param::PARAM_INPUT, $row['CDREGIAO'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFORNECED', Param::PARAM_INPUT, $row['CDFORNECED'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDCOMPRADOR', Param::PARAM_INPUT, $row['CDCOMPRADOR'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_DTINIVALITM', Param::PARAM_INPUT, $dtIniValItm, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_DTFINVALITM', Param::PARAM_INPUT, $dtFinValItm, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODINI', Param::PARAM_INPUT, $row['CDPRODINI'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDPRODFIN', Param::PARAM_INPUT, $row['CDPRODFIN'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDMARCA', Param::PARAM_INPUT, $row['CDMARCA'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_DTINIVALANT', Param::PARAM_INPUT, $dtIniValAnt, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_DTFINVALANT', Param::PARAM_INPUT, $dtFinValAnt, Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_MELHORPRECO', Param::PARAM_INPUT, $row['PARAMMELHORPRECO'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['CDFILIAL'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_IDVERIFICAVRIT', Param::PARAM_INPUT, $row['IDVERIFICAVRIT'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_IDTPCOMPARA', Param::PARAM_INPUT, $row['PARAMCOMPPRECO'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $row['NRORG'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_EXIBE', Param::PARAM_INPUT, $row['EXIBE'], Param::PARAM_TYPE_STR));
      
      $procedure->execute();
  }
  
  private function executeProcedureApuraMelhorEqualizacao($row)
	{
      $procedure = new StoredProcedure($this->connection, 'APURA_MELHOR_EQUALIZA');
      $procedure->addParam(new Param('P_CDCENTCMP', Param::PARAM_INPUT, $row['CDFILIAL'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_NREQUALFORNE', Param::PARAM_INPUT, $row['NRSEQAPUR'], Param::PARAM_TYPE_STR));
      $procedure->addParam(new Param('P_IDMELHORPRECO', Param::PARAM_INPUT, $row['PARAMMELHORPRECO'], Param::PARAM_TYPE_STR));
      $procedure->execute();
  }

}